==> eam-wshub-proxyclient-11.5-10-sources.jar: net/datastream/schemas/mp_fields/CREWQUALIFICATIONS_Type.java <==

package net.datastream.schemas.mp_fields;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Classe Java pour CREWQUALIFICATIONS_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="CREWQUALIFICATIONS_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CREWID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}NUMOFEMPLOYEES" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DISPATCHEDHOURS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EMPLOYEEQUALIFICATIONS" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PROFILEPICTURE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}REMAININGAVAILABLEHRS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UPLOADEDDATE" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CREWQUALIFICATIONS_Type", propOrder = {
    "crewid",
    "numofemployees",
    "dispatchedhours",
    "employeequalifications",
    "profilepicture",
    "remainingavailablehrs",
    "uploadeddate"
})
public class CREWQUALIFICATIONS_Type {

    @XmlElement(name = "CREWID", required = true)
    protected CREWID_Type crewid;
    @XmlElement(name = "NUMOFEMPLOYEES")
    protected Long numofemployees;
    @XmlElement(name = "DISPATCHEDHOURS")
    protected QUANTITY dispatchedhours;
    @XmlElement(name = "EMPLOYEEQUALIFICATIONS")
    protected List<EMPLOYEEQUALIFICATIONS_Type> employeequalifications;
    @XmlElement(name = "PROFILEPICTURE")
    protected DOCUMENTID_Type profilepicture;
    @XmlElement(name = "REMAININGAVAILABLEHRS")
    protected QUANTITY remainingavailablehrs;
    @XmlElement(name = "UPLOADEDDATE")
    protected DATETIME uploadeddate;

    /**
     * Obtient la valeur de la propriété crewid.
     * 
     * @return
     *     possible object is
     *     {@link CREWID_Type }
     *     
     */
    public CREWID_Type getCREWID() {
        return crewid;
    }

    /**
     * Définit la valeur de la propriété crewid.
     * 
     * @param value
     *     allowed object is
     *     {@link CREWID_Type }
     *     
     */
    public void setCREWID(CREWID_Type value) {
        this.crewid = value;
    }

    /**
     * Obtient la valeur de la propriété numofemployees.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getNUMOFEMPLOYEES() {
        return numofemployees;
    }

    /**
     * Définit la valeur de la propriété numofemployees.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setNUMOFEMPLOYEES(Long value) {
        this.numofemployees = value;
    }

    /**
     * Obtient la valeur de la propriété dispatchedhours.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getDISPATCHEDHOURS() {
        return dispatchedhours;
    }

    /**
     * Définit la valeur de la propriété dispatchedhours.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setDISPATCHEDHOURS(QUANTITY value) {
        this.dispatchedhours = value;
    }

    /**
     * Gets the value of the employeequalifications property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the employeequalifications property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getEMPLOYEEQUALIFICATIONS().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link EMPLOYEEQUALIFICATIONS_Type }
     * 
     * 
     */
    public List<EMPLOYEEQUALIFICATIONS_Type> getEMPLOYEEQUALIFICATIONS() {
        if (employeequalifications == null) {
            employeequalifications = new ArrayList<EMPLOYEEQUALIFICATIONS_Type>();
        }
        return this.employeequalifications;
    }

    /**
     * Obtient la valeur de la propriété profilepicture.
     * 
     * @return
     *     possible object is
     *     {@link DOCUMENTID_Type }
     *     
     */
    public DOCUMENTID_Type getPROFILEPICTURE() {
        return profilepicture;
    }

    /**
     * Définit la valeur de la propriété profilepicture.
     * 
     * @param value
     *     allowed object is
     *     {@link DOCUMENTID_Type }
     *     
     */
    public void setPROFILEPICTURE(DOCUMENTID_Type value) {
        this.profilepicture = value;
    }

    /**
     * Obtient la valeur de la propriété remainingavailablehrs.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getREMAININGAVAILABLEHRS() {
        return remainingavailablehrs;
    }

    /**
     * Définit la valeur de la propriété remainingavailablehrs.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setREMAININGAVAILABLEHRS(QUANTITY value) {
        this.remainingavailablehrs = value;
    }

    /**
     * Obtient la valeur de la propriété uploadeddate.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getUPLOADEDDATE() {
        return uploadeddate;
    }

    /**
     * Définit la valeur de la propriété uploadeddate.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setUPLOADEDDATE(DATETIME value) {
        this.uploadeddate = value;
    }

}

==> eam-wshub-proxyclient-11.7-0-sources.jar: net/datastream/schemas/mp_fields/CREWQUALIFICATIONS_Type.java <==

package net.datastream.schemas.mp_fields;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for CREWQUALIFICATIONS_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CREWQUALIFICATIONS_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CREWID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}NUMOFEMPLOYEES" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DISPATCHEDHOURS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EMPLOYEEQUALIFICATIONS" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PROFILEPICTURE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}REMAININGAVAILABLEHRS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UPLOADEDDATE" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CREWQUALIFICATIONS_Type", propOrder = {
    "crewid",
    "numofemployees",
    "dispatchedhours",
    "employeequalifications",
    "profilepicture",
    "remainingavailablehrs",
    "uploadeddate"
})
public class CREWQUALIFICATIONS_Type {

    @XmlElement(name = "CREWID", required = true)
    protected CREWID_Type crewid;
    @XmlElement(name = "NUMOFEMPLOYEES")
    protected Long numofemployees;
    @XmlElement(name = "DISPATCHEDHOURS")
    protected QUANTITY dispatchedhours;
    @XmlElement(name = "EMPLOYEEQUALIFICATIONS")
    protected List<EMPLOYEEQUALIFICATIONS_Type> employeequalifications;
    @XmlElement(name = "PROFILEPICTURE")
    protected DOCUMENTID_Type profilepicture;
    @XmlElement(name = "REMAININGAVAILABLEHRS")
    protected QUANTITY remainingavailablehrs;
    @XmlElement(name = "UPLOADEDDATE")
    protected DATETIME uploadeddate;

    /**
     * Gets the value of the crewid property.
     * 
     * @return
     *     possible object is
     *     {@link CREWID_Type }
     *     
     */
    public CREWID_Type getCREWID() {
        return crewid;
    }

    /**
     * Sets the value of the crewid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CREWID_Type }
     *     
     */
    public void setCREWID(CREWID_Type value) {
        this.crewid = value;
    }

    /**
     * Gets the value of the numofemployees property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getNUMOFEMPLOYEES() {
        return numofemployees;
    }

    /**
     * Sets the value of the numofemployees property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setNUMOFEMPLOYEES(Long value) {
        this.numofemployees = value;
    }

    /**
     * Gets the value of the dispatchedhours property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getDISPATCHEDHOURS() {
        return dispatchedhours;
    }

    /**
     * Sets the value of the dispatchedhours property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setDISPATCHEDHOURS(QUANTITY value) {
        this.dispatchedhours = value;
    }

    /**
     * Gets the value of the employeequalifications property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the employeequalifications property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getEMPLOYEEQUALIFICATIONS().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link EMPLOYEEQUALIFICATIONS_Type }
     * 
     * 
     */
    public List<EMPLOYEEQUALIFICATIONS_Type> getEMPLOYEEQUALIFICATIONS() {
        if (employeequalifications == null) {
            employeequalifications = new ArrayList<EMPLOYEEQUALIFICATIONS_Type>();
        }
        return this.employeequalifications;
    }

    /**
     * Gets the value of the profilepicture property.
     * 
     * @return
     *     possible object is
     *     {@link DOCUMENTID_Type }
     *     
     */
    public DOCUMENTID_Type getPROFILEPICTURE() {
        return profilepicture;
    }

    /**
     * Sets the value of the profilepicture property.
     * 
     * @param value
     *     allowed object is
     *     {@link DOCUMENTID_Type }
     *     
     */
    public void setPROFILEPICTURE(DOCUMENTID_Type value) {
        this.profilepicture = value;
    }

    /**
     * Gets the value of the remainingavailablehrs property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getREMAININGAVAILABLEHRS() {
        return remainingavailablehrs;
    }

    /**
     * Sets the value of the remainingavailablehrs property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setREMAININGAVAILABLEHRS(QUANTITY value) {
        this.remainingavailablehrs = value;
    }

    /**
     * Gets the value of the uploadeddate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getUPLOADEDDATE() {
        return uploadeddate;
    }

    /**
     * Sets the value of the uploadeddate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setUPLOADEDDATE(DATETIME value) {
        this.uploadeddate = value;
    }

}
